@@ -35,7 +35,7 @@ package Crypt::Blowfish;
 use strict;
 use vars qw($VERSION);
 
-$VERSION="1.00";
+$VERSION="1.01";
 
 =head2 B<new>(I<key>)
 
@@ -453,6 +453,16 @@ sub decrypt
 	return pack("NN",$r,$l);
 	}
 
+sub blocksize
+	{
+	return 8;
+	}
+
+sub keysize
+	{
+	return 18;
+	}
+
 =head1 COMMENTS
 
 This is probably crap software, but hey, its for general use. I'm happy to patch
